searchNodes=[{"type":"module","title":"HL7","doc":"Functions to manipulate and query HL7 documents -- plus a way to handle HL7 file streams.","ref":"HL7.html"},{"type":"function","title":"HL7.chunk_by_lead_segment/3","doc":"Creates a list of lists in which the specified segment_name is used to get the first segment map of each list. This function helps to do things like grouping OBX segments with their parent OBR segment. Options: keep_prefix_segments: true will leave the first set of non-matching segments in the return value.","ref":"HL7.html#chunk_by_lead_segment/3"},{"type":"function","title":"HL7.do_to_list/1","doc":"","ref":"HL7.html#do_to_list/1"},{"type":"function","title":"HL7.get/2","doc":"Finds data within an HL7.t() and from within the data that get/2 returns (segments and repetitions) using an HL7.Path sigil. Selecting data across multiple segments or repetitions with the wildcard [*] pattern will return a list of results. Repetition data can be search using a partial path containing ony the component and/or subcomponent with the preceding period, e.g. ~p&quot;.2.3&quot; . Examples iex&gt; import HL7 , only : :sigils iex&gt; HL7.Examples . wikipedia_sample_hl7 ( ) ...&gt; |&gt; HL7 . new! ( ) ...&gt; |&gt; HL7 . get ( ~p&quot;OBX-5&quot; ) &quot;1.80&quot; iex&gt; import HL7 , only : :sigils iex&gt; HL7.Examples . wikipedia_sample_hl7 ( ) ...&gt; |&gt; HL7 . new! ( ) ...&gt; |&gt; HL7 . get ( ~p&quot;OBX[*]-5&quot; ) [ &quot;1.80&quot; , &quot;79&quot; ] iex&gt; import HL7 , only : :sigils iex&gt; HL7.Examples . wikipedia_sample_hl7 ( ) ...&gt; |&gt; HL7 . new! ( ) ...&gt; |&gt; HL7 . get ( ~p&quot;OBX[*]-2!&quot; ) [ &quot;N&quot; , &quot;NM&quot; ] iex&gt; import HL7 , only : :sigils iex&gt; HL7.Examples . wikipedia_sample_hl7 ( ) ...&gt; |&gt; HL7 . new! ( ) ...&gt; |&gt; HL7 . get ( ~p&quot;PID-11[*].5&quot; ) [ &quot;35209&quot; , &quot;35200&quot; ] iex&gt; import HL7 , only : :sigils iex&gt; HL7.Examples . wikipedia_sample_hl7 ( ) ...&gt; |&gt; HL7 . new! ( ) ...&gt; |&gt; HL7 . get ( ~p&quot;PID-11[2].1&quot; ) &quot;NICKELL’S PICKLES&quot; iex&gt; import HL7 , only : :sigils iex&gt; HL7.Examples . wikipedia_sample_hl7 ( ) ...&gt; |&gt; HL7 . new! ( ) ...&gt; |&gt; HL7 . get ( ~p&quot;PID-11[*]&quot; ) ...&gt; |&gt; HL7 . get ( ~p&quot;.1&quot; ) [ &quot;260 GOODWIN CREST DRIVE&quot; , &quot;NICKELL’S PICKLES&quot; ]","ref":"HL7.html#get/2"},{"type":"function","title":"HL7.get_segments/1","doc":"","ref":"HL7.html#get_segments/1"},{"type":"function","title":"HL7.label/2","doc":"Labels source data (a segment map or list of segment maps) by using HL7.Path sigils in a labeled output template. One-arity functions placed as output template values will be called with the source data. Examples iex&gt; import HL7 , only : :sigils iex&gt; HL7.Examples . wikipedia_sample_hl7 ( ) ...&gt; |&gt; HL7 . new! ( ) ...&gt; |&gt; HL7 . label ( %{ mrn : ~p&quot;PID-3!&quot; , name : ~p&quot;PID-5.2&quot; } ) %{ mrn : &quot;56782445&quot; , name : &quot;BARRY&quot; }","ref":"HL7.html#label/2"},{"type":"function","title":"HL7.new/1","doc":"","ref":"HL7.html#new/1"},{"type":"function","title":"HL7.new!/1","doc":"Creates an HL7 struct from HL7 data (accepting text, lists or the deprecated HL7.Message struct).","ref":"HL7.html#new!/1"},{"type":"function","title":"HL7.open_hl7_file_stream/2","doc":"Opens an HL7 file stream of either :mllp or :line . If the file_type is not specified it will be inferred from the first three characters of the file contents.","ref":"HL7.html#open_hl7_file_stream/2"},{"type":"function","title":"HL7.put/3","doc":"","ref":"HL7.html#put/3"},{"type":"function","title":"HL7.set_segments/2","doc":"","ref":"HL7.html#set_segments/2"},{"type":"macro","title":"HL7.sigil_p/2","doc":"The ~p sigil encodes an HL7 path into a struct at compile-time to guarantee correctness and speed. It is designed to work with data returned by HL7.new!/1 . The full path structure in HL7 is expressed as: ~p&quot;SEGMENT_NAME[SEGMENT_NUMBER]-FIELD[REPETITION].COMPONENT.SUBCOMPONENT SEGMENT_NAME -- 3 character string SEGMENT_NUMBER -- Positive integer in brackets, defaulting to 1. All segments of the name can be accessed with [*] FIELD -- Positive integer REPETITION -- Positive integer in brackets, defaulting to 1. All repetitions of the field can be accessed with [*] COMPONENT -- Positive integer SUBCOMPONENT -- Positive integer Example paths: ~p&quot;OBX&quot; refers to the 1st OBX segment in its entirety, the same as ~p&quot;OBX[1]&quot; . ~p&quot;OBX-5&quot; means the 1st repetition of the 5th field of the 1st OBX segment. ~p&quot;OBX[1]-5[1]&quot; is equivalent, the numbers in brackets specifying the default repetition and segment number values. ~p&quot;OBX[2]-5&quot; thus means 1st repetition of the 5th field of the 2nd OBX segment. ~p&quot;OBX[*]-5&quot; would get the 1st repetition of the 5th field of every OBX segment, returning a list of results. Note that repetitions are uncommon in HL7 and the default of a 1st repetition is often just assumed. ~p&quot;PID-3&quot; is equivalent to ~p&quot;PID-3[1]&quot; and is the most standard representation. All repetitions can be found using a repetition wildcard: ~p&quot;PID-11[*]&quot; . A list of lists can be produced by selecting multiple segments and multiple repetitions with ~p&quot;PID[*]-11[*]&quot; . Components and subcomponents can also be accessed with the path structures. h&quot;OBX-2.3.1&quot; would return the 1st subcomponent of the 3rd component of the 2nd field of the 1st OBX. Lastly, if a path might have additional data such that a string might be found at either ~p&quot;OBX-2&quot; or ~p&quot;OBX-2.1&quot; or even ~p&quot;OBX-2.1.1&quot; , there is truncation character (the bang symbol) that will return the first element found in the HL7 text at the target specificity. Thus, ~p&quot;OBX[*]-2!&quot; would get the 1st piece of data in the 2nd field of every OBX whether it is a string or nested map. Examples iex&gt; import HL7 iex&gt; HL7.Examples . wikipedia_sample_hl7 ( ) ...&gt; |&gt; HL7 . new! ( ) ...&gt; |&gt; HL7 . get ( ~p&quot;OBX-5&quot; ) &quot;1.80&quot; iex&gt; import HL7 iex&gt; HL7.Examples . wikipedia_sample_hl7 ( ) ...&gt; |&gt; HL7 . new! ( ) ...&gt; |&gt; HL7 . get ( ~p&quot;OBX[*]-5&quot; ) [ &quot;1.80&quot; , &quot;79&quot; ] iex&gt; import HL7 iex&gt; HL7.Examples . wikipedia_sample_hl7 ( ) ...&gt; |&gt; HL7 . new! ( ) ...&gt; |&gt; HL7 . get ( ~p&quot;OBX[*]-2!&quot; ) [ &quot;N&quot; , &quot;NM&quot; ] iex&gt; import HL7 iex&gt; HL7.Examples . wikipedia_sample_hl7 ( ) ...&gt; |&gt; HL7 . new! ( ) ...&gt; |&gt; HL7 . get ( ~p&quot;PID-11[*].5&quot; ) [ &quot;35209&quot; , &quot;35200&quot; ] iex&gt; import HL7 iex&gt; HL7.Examples . wikipedia_sample_hl7 ( ) ...&gt; |&gt; HL7 . new! ( ) ...&gt; |&gt; HL7 . get ( ~p&quot;PID[*]-11[*].5&quot; ) [ [ &quot;35209&quot; , &quot;35200&quot; ] ] iex&gt; import HL7 iex&gt; HL7.Examples . wikipedia_sample_hl7 ( ) ...&gt; |&gt; HL7 . new! ( ) ...&gt; |&gt; HL7 . get ( ~p&quot;PID-11[2].1&quot; ) &quot;NICKELL’S PICKLES&quot;","ref":"HL7.html#sigil_p/2"},{"type":"function","title":"HL7.to_list/1","doc":"Converts a segment map (or lists of segments maps) or HL7 struct into a raw Elixir list.","ref":"HL7.html#to_list/1"},{"type":"function","title":"HL7.update/4","doc":"","ref":"HL7.html#update/4"},{"type":"function","title":"HL7.update!/3","doc":"","ref":"HL7.html#update!/3"},{"type":"type","title":"HL7.file_type_hl7/0","doc":"","ref":"HL7.html#t:file_type_hl7/0"},{"type":"type","title":"HL7.hl7_list_data/0","doc":"","ref":"HL7.html#t:hl7_list_data/0"},{"type":"type","title":"HL7.hl7_map_data/0","doc":"","ref":"HL7.html#t:hl7_map_data/0"},{"type":"type","title":"HL7.parsed_hl7/0","doc":"","ref":"HL7.html#t:parsed_hl7/0"},{"type":"type","title":"HL7.parsed_hl7_segments/0","doc":"","ref":"HL7.html#t:parsed_hl7_segments/0"},{"type":"type","title":"HL7.segment/0","doc":"","ref":"HL7.html#t:segment/0"},{"type":"type","title":"HL7.t/0","doc":"","ref":"HL7.html#t:t/0"},{"type":"module","title":"HL7.Examples","doc":"Functions to provide sample HL7 data which can be used to explore the API.","ref":"HL7.Examples.html"},{"type":"function","title":"HL7.Examples.elr_example/0","doc":"","ref":"HL7.Examples.html#elr_example/0"},{"type":"function","title":"HL7.Examples.nist_immunization_hl7/0","doc":"","ref":"HL7.Examples.html#nist_immunization_hl7/0"},{"type":"function","title":"HL7.Examples.nist_syndromic_hl7/0","doc":"","ref":"HL7.Examples.html#nist_syndromic_hl7/0"},{"type":"function","title":"HL7.Examples.wikipedia_sample_hl7/1","doc":"Returns a sample HL7 string from Wikipedia's HL7 article . The HL7 version of the message defaults to 2.5, but can be overidden.","ref":"HL7.Examples.html#wikipedia_sample_hl7/1"},{"type":"function","title":"HL7.Examples.wikipedia_sample_hl7_alt_delimiters/0","doc":"","ref":"HL7.Examples.html#wikipedia_sample_hl7_alt_delimiters/0"},{"type":"module","title":"HL7.FieldGrammar","doc":"","ref":"HL7.FieldGrammar.html"},{"type":"function","title":"HL7.FieldGrammar.to_indices/1","doc":"","ref":"HL7.FieldGrammar.html#to_indices/1"},{"type":"module","title":"HL7.Header","doc":"An HL7 header implementation that can be used to build MSH segments and HL7 messages. It is also exposed as metadata after parsing any HL7 message.","ref":"HL7.Header.html"},{"type":"function","title":"HL7.Header.get_message_date_time/0","doc":"","ref":"HL7.Header.html#get_message_date_time/0"},{"type":"function","title":"HL7.Header.get_message_type_field/1","doc":"","ref":"HL7.Header.html#get_message_type_field/1"},{"type":"function","title":"HL7.Header.new/5","doc":"","ref":"HL7.Header.html#new/5"},{"type":"function","title":"HL7.Header.to_msh/1","doc":"","ref":"HL7.Header.html#to_msh/1"},{"type":"type","title":"HL7.Header.t/0","doc":"","ref":"HL7.Header.html#t:t/0"},{"type":"module","title":"HL7.InvalidGrammar","doc":"Contains information concerning any failed attempt to parse Field or Segment Grammar Notations.","ref":"HL7.InvalidGrammar.html"},{"type":"function","title":"HL7.InvalidGrammar.invalid_token/2","doc":"","ref":"HL7.InvalidGrammar.html#invalid_token/2"},{"type":"function","title":"HL7.InvalidGrammar.no_required_segments/0","doc":"","ref":"HL7.InvalidGrammar.html#no_required_segments/0"},{"type":"type","title":"HL7.InvalidGrammar.invalid_token/0","doc":"","ref":"HL7.InvalidGrammar.html#t:invalid_token/0"},{"type":"type","title":"HL7.InvalidGrammar.no_required_segments/0","doc":"","ref":"HL7.InvalidGrammar.html#t:no_required_segments/0"},{"type":"type","title":"HL7.InvalidGrammar.t/0","doc":"","ref":"HL7.InvalidGrammar.html#t:t/0"},{"type":"module","title":"HL7.InvalidHeader","doc":"Contains information concerning any failed attempt to parse an HL7 MSH segment.","ref":"HL7.InvalidHeader.html"},{"type":"type","title":"HL7.InvalidHeader.t/0","doc":"","ref":"HL7.InvalidHeader.html#t:t/0"},{"type":"module","title":"HL7.InvalidMessage","doc":"Contains information concerning any failed attempt to parse an HL7 message, generally MSH-related.","ref":"HL7.InvalidMessage.html"},{"type":"type","title":"HL7.InvalidMessage.t/0","doc":"","ref":"HL7.InvalidMessage.html#t:t/0"},{"type":"module","title":"HL7.Lexers.Default","doc":"","ref":"HL7.Lexers.Default.html"},{"type":"function","title":"HL7.Lexers.Default.tokenize/1","doc":"","ref":"HL7.Lexers.Default.html#tokenize/1"},{"type":"module","title":"HL7.Lexers.DefaultWithCopy","doc":"","ref":"HL7.Lexers.DefaultWithCopy.html"},{"type":"function","title":"HL7.Lexers.DefaultWithCopy.tokenize/1","doc":"","ref":"HL7.Lexers.DefaultWithCopy.html#tokenize/1"},{"type":"module","title":"HL7.Lexers.Dynamic","doc":"","ref":"HL7.Lexers.Dynamic.html"},{"type":"function","title":"HL7.Lexers.Dynamic.tokenize/1","doc":"","ref":"HL7.Lexers.Dynamic.html#tokenize/1"},{"type":"function","title":"HL7.Lexers.Dynamic.tokenize/2","doc":"","ref":"HL7.Lexers.Dynamic.html#tokenize/2"},{"type":"module","title":"HL7.Lexers.DynamicWithCopy","doc":"","ref":"HL7.Lexers.DynamicWithCopy.html"},{"type":"function","title":"HL7.Lexers.DynamicWithCopy.tokenize/1","doc":"","ref":"HL7.Lexers.DynamicWithCopy.html#tokenize/1"},{"type":"function","title":"HL7.Lexers.DynamicWithCopy.tokenize/2","doc":"","ref":"HL7.Lexers.DynamicWithCopy.html#tokenize/2"},{"type":"module","title":"HL7.Message","doc":"Creates, parses and modifies HL7 messages with a focus on performance. Contains a list of parsed segments and header metadata. Use Hl7.Message.new/2 to create an Hl7.Message struct that contains a fully parsed HL7 message alongside header metadata. The parsed data is represented as minimally as possible as lists of string and lists. The second argument is an options map supporting the following values: copy: true -- Will create binary copies while parsing to avoid keeping references. validate_string: true -- Will generate an HL7.InvalidMessage if the source text is not UTF-8 compatible.","ref":"HL7.Message.html"},{"type":"function","title":"HL7.Message.find/2","doc":"Returns the first parsed segment matching segment_name from an HL7 message or content.","ref":"HL7.Message.html#find/2"},{"type":"function","title":"HL7.Message.new/2","doc":"Creates an HL7.Message struct containing parsed segment list data. It will also expose basic header information (e.g. encoding characters, message type) for routing. Pass copy: true as the second argument to generate binary copies of all substrings as it parses the message. Invalid MSH formats will return an HL7.InvalidMessage . Examples iex&gt; HL7.Examples . wikipedia_sample_hl7 ( ) ...&gt; |&gt; HL7.Message . new ( ) ...&gt; |&gt; HL7.Query . get_segment_names ( ) [ &quot;MSH&quot; , &quot;EVN&quot; , &quot;PID&quot; , &quot;PV1&quot; , &quot;OBX&quot; , &quot;OBX&quot; , &quot;AL1&quot; , &quot;DG1&quot; ] iex&gt; HL7.Message . new ( ...&gt; &quot;MSH|^~ \\\\ &amp;|MegaReg|XYZHospC|SuperOE|XYZImgCtr|&quot; &lt;&gt; ...&gt; &quot;20060529090131-0500||ADT^A01^ADT_A01|01052901|P|2.5&quot; ) ...&gt; |&gt; HL7.Query . get_segment_names ( ) [ &quot;MSH&quot; ] iex&gt; HL7.Message . new ( ...&gt; [ [ &quot;MSH&quot; , &quot;|&quot; , &quot;^~ \\\\ &amp;&quot; , &quot;App&quot; , &quot;Facility&quot; , &quot;&quot; , &quot;&quot; , ...&gt; &quot;20060529090131-0500&quot; , &quot;&quot; , [ [ &quot;ADT&quot; , &quot;A01&quot; , &quot;ADT_A01&quot; ] ] , ...&gt; &quot;01052901&quot; , &quot;P&quot; , &quot;2.5&quot; ] ] ) ...&gt; |&gt; HL7.Query . get_segment_names ( ) [ &quot;MSH&quot; ]","ref":"HL7.Message.html#new/2"},{"type":"function","title":"HL7.Message.raw/1","doc":"Creates an HL7.Message struct containing the raw HL7 text for further processing. It will also expose basic header information (e.g. encoding characters, message type) for routing. Invalid MSH formats will return an HL7.InvalidMessage struct.","ref":"HL7.Message.html#raw/1"},{"type":"function","title":"HL7.Message.to_list/1","doc":"Returns a parsed list of segments from an HL7 message or content.","ref":"HL7.Message.html#to_list/1"},{"type":"type","title":"HL7.Message.content_hl7/0","doc":"","ref":"HL7.Message.html#t:content_hl7/0"},{"type":"type","title":"HL7.Message.fragment_hl7/0","doc":"","ref":"HL7.Message.html#t:fragment_hl7/0"},{"type":"type","title":"HL7.Message.parsed_hl7/0","doc":"","ref":"HL7.Message.html#t:parsed_hl7/0"},{"type":"type","title":"HL7.Message.raw_hl7/0","doc":"","ref":"HL7.Message.html#t:raw_hl7/0"},{"type":"type","title":"HL7.Message.segment_hl7/0","doc":"","ref":"HL7.Message.html#t:segment_hl7/0"},{"type":"type","title":"HL7.Message.t/0","doc":"","ref":"HL7.Message.html#t:t/0"},{"type":"module","title":"HL7.Parser","doc":"","ref":"HL7.Parser.html"},{"type":"function","title":"HL7.Parser.parse/3","doc":"","ref":"HL7.Parser.html#parse/3"},{"type":"module","title":"HL7.Path","doc":"","ref":"HL7.Path.html"},{"type":"function","title":"HL7.Path.new/1","doc":"Generates an ~p sigil data structure at runtime. Examples iex&gt; HL7.Examples . wikipedia_sample_hl7 ( ) ...&gt; |&gt; HL7 . new! ( ) ...&gt; |&gt; HL7 . get ( HL7.Path . new ( &quot;OBX-5&quot; ) ) &quot;1.80&quot;","ref":"HL7.Path.html#new/1"},{"type":"type","title":"HL7.Path.level/0","doc":"","ref":"HL7.Path.html#t:level/0"},{"type":"type","title":"HL7.Path.t/0","doc":"","ref":"HL7.Path.html#t:t/0"},{"type":"module","title":"HL7.PathParser","doc":"","ref":"HL7.PathParser.html"},{"type":"function","title":"HL7.PathParser.parse/2","doc":"Parses the given binary as parse. Returns {:ok, [token], rest, context, position, byte_offset} or {:error, reason, rest, context, line, byte_offset} where position describes the location of the parse (start position) as {line, offset_to_start_of_line} . To column where the error occurred can be inferred from byte_offset - offset_to_start_of_line . Options :byte_offset - the byte offset for the whole binary, defaults to 0 :line - the line and the byte offset into that line, defaults to {1, byte_offset} :context - the initial context value. It will be converted to a map","ref":"HL7.PathParser.html#parse/2"},{"type":"module","title":"HL7.Query","doc":"Queries and modifies HL7 messages using Field and Segment Grammar Notations with a pipeline-friendly API and set-based operations. Similar to libraries such as jQuery and D3, HL7.Query is designed around the concept of selecting and sub-selecting elements (segments or segment groups) in an HL7 message. The full message context is retained in the HL7.Query struct so that messages can be modified piecemeal and then reconstructed as strings. In general, use HL7.Query.select/2 with a segment selector (similar to CSS selectors) to select lists of segment groups. The segment selector is written as a string of ordered segment names. Curly braces surround repeating elements. Square brackets enclose optional elements. These can be nested to create selectors that can select complex groups of segments or validate entire HL7 message layouts. For example, an ORU_R01 HL7 message's Order Group selector could be written as: &quot;[ORC] OBR {[NTE]} {[OBX {[NTE]}]}&quot; . Note that this would look for OBRs, optionally preceded by an ORC, possibly followed by one or more NTEs, maybe followed again by one or more OBRs with their own optional NTE sets. To reference data within segments, there is a field selector format that can access fields, repetitions, components and sub-components across one or more segments. All indices start at one, and the repetition index defaults to one unless specified within brackets after the field number. Field Selector Description &quot;PID-11[2].4&quot; PID segments, 11th field, 2nd repetition, 4th component &quot;OBX-2.2.1&quot; OBX segments, 2nd field, 2nd component, 1st sub-component &quot;1&quot; All segments, 1st field &quot;3[4].2&quot; All segments, 3rd field, 4th repetition, 2nd component","ref":"HL7.Query.html"},{"type":"function","title":"HL7.Query.append/2","doc":"Appends a segment or segments to the currently selected segments in each selection.","ref":"HL7.Query.html#append/2"},{"type":"function","title":"HL7.Query.count/1","doc":"Returns the current selection count.","ref":"HL7.Query.html#count/1"},{"type":"function","title":"HL7.Query.data/2","doc":"Associates data with each selection. This data remains accessible to child selections. Each selection stores a map of data. The supplied fun should accept an HL7.Query and return a map of key-values to be merged into the existing map of data. Selections automatically include the index of the current selection, i.e., %{index: 5} . For HL7 numbering, the index values begin at 1. Examples iex&gt; import HL7.Query iex&gt; HL7.Examples . nist_immunization_hl7 ( ) ...&gt; |&gt; select ( &quot;ORC RXA RXR {[OBX]}&quot; ) ...&gt; |&gt; data ( fn q -&gt; %{ order_num : find_first ( q , ~p&quot;ORC-3.1&quot; ) } end ) ...&gt; |&gt; select ( &quot;OBX&quot; ) ...&gt; |&gt; update ( ~p&quot;6&quot; , fn q -&gt; get_datum ( q , :order_num ) end ) ...&gt; |&gt; root ( ) ...&gt; |&gt; find_first ( ~p&quot;OBX-6&quot; ) &quot;IZ-783278&quot; iex&gt; import HL7.Query iex&gt; HL7.Examples . nist_immunization_hl7 ( ) ...&gt; |&gt; select ( &quot;ORC RXA RXR {[OBX]}&quot; ) ...&gt; |&gt; data ( fn q -&gt; %{ group_num : get_index ( q ) } end ) ...&gt; |&gt; select ( &quot;OBX&quot; ) ...&gt; |&gt; update ( ~p&quot;6&quot; , fn q -&gt; get_datum ( q , :group_num ) end ) ...&gt; |&gt; root ( ) ...&gt; |&gt; find_all ( ~p&quot;OBX-6&quot; ) [ 1 , 1 , 1 , 1 , 2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 , 2 ]","ref":"HL7.Query.html#data/2"},{"type":"function","title":"HL7.Query.delete/1","doc":"Deletes all selections in the query document.","ref":"HL7.Query.html#delete/1"},{"type":"function","title":"HL7.Query.filter/2","doc":"Filters (deletes) segments within selections by whitelisting one or more segment types. Accepts either a segment name, list of acceptable names, or a function that takes an HL7.Query (containing one sub-selected segment at a time) and returns a boolean filter value. Examples iex&gt; import HL7.Query iex&gt; HL7.Examples . nist_immunization_hl7 ( ) ...&gt; |&gt; filter ( [ &quot;MSH&quot; , &quot;PID&quot; , &quot;ORC&quot; ] ) ...&gt; |&gt; root ( ) ...&gt; |&gt; get_segment_names ( ) [ &quot;MSH&quot; , &quot;PID&quot; , &quot;ORC&quot; , &quot;ORC&quot; , &quot;ORC&quot; ]","ref":"HL7.Query.html#filter/2"},{"type":"function","title":"HL7.Query.find_all/2","doc":"Returns a flattened list of segment parts from selected segments across all selections using the given field_selector . PID-3[2].1.2 PID segments, field 3, repetition 2, component 1, subcomponent 2 OBX-5 OBX segments, field 5 2.3 All segments, field 2, component 3","ref":"HL7.Query.html#find_all/2"},{"type":"function","title":"HL7.Query.find_first/2","doc":"Returns a segment part from the first selected segment (of the given name, if specified) across all selections using the given field_selector . PID-3[2].1.2 PID segments, field 3, repetition 2, component 1, subcomponent 2 OBX-5 OBX segments, field 5 2.3 All segments, field 2, component 3","ref":"HL7.Query.html#find_first/2"},{"type":"function","title":"HL7.Query.get_data/1","doc":"Returns a list containing an associated data map for each selection in the given HL7.Query .","ref":"HL7.Query.html#get_data/1"},{"type":"function","title":"HL7.Query.get_datum/3","doc":"Returns the associated key-value of the first (or only) selection for the given HL7.Query .","ref":"HL7.Query.html#get_datum/3"},{"type":"function","title":"HL7.Query.get_index/1","doc":"Returns the selection index of the first (or only) selection for the given HL7.Query . Examples iex&gt; import HL7.Query iex&gt; HL7.Examples . nist_immunization_hl7 ( ) ...&gt; |&gt; select ( &quot;ORC RXA RXR {[OBX]}&quot; ) ...&gt; |&gt; map ( fn q -&gt; get_index ( q ) end ) [ 1 , 2 ] iex&gt; import HL7.Query iex&gt; HL7.Examples . nist_immunization_hl7 ( ) ...&gt; |&gt; select ( &quot;ORC RXA RXR {[OBX]}&quot; ) ...&gt; |&gt; select ( &quot;OBX&quot; ) ...&gt; |&gt; map ( fn q -&gt; get_index ( q ) end ) [ 1 , 2 , 3 , 4 , 1 , 2 , 3 , 4 , 5 , 6 , 7 , 8 , 9 , 10 ] iex&gt; import HL7.Query iex&gt; HL7.Examples . nist_immunization_hl7 ( ) ...&gt; |&gt; select ( &quot;OBX&quot; ) ...&gt; |&gt; map ( fn q -&gt; get_index ( q ) end ) [ 1 , 2 , 3 , 4 , 5 , 6 , 7 , 8 , 9 , 10 , 11 , 12 , 13 , 14 ]","ref":"HL7.Query.html#get_index/1"},{"type":"function","title":"HL7.Query.get_part/2","doc":"","ref":"HL7.Query.html#get_part/2"},{"type":"function","title":"HL7.Query.get_parts/2","doc":"","ref":"HL7.Query.html#get_parts/2"},{"type":"function","title":"HL7.Query.get_segment_groups/1","doc":"Returns a list containing a list of selected segments for each selection.","ref":"HL7.Query.html#get_segment_groups/1"},{"type":"function","title":"HL7.Query.get_segment_names/1","doc":"Returns a flattened list of segment names across all selections.","ref":"HL7.Query.html#get_segment_names/1"},{"type":"function","title":"HL7.Query.get_segments/1","doc":"Returns a flattened list of selected segments across all selections.","ref":"HL7.Query.html#get_segments/1"},{"type":"function","title":"HL7.Query.map/2","doc":"Maps across each selection with a fun that accepts an HL7.Query (handling one selection at a time) and returns a results list. Examples iex&gt; import HL7.Query iex&gt; HL7.Examples . nist_immunization_hl7 ( ) ...&gt; |&gt; select ( &quot;RXA&quot; ) ...&gt; |&gt; map ( fn q -&gt; find_first ( q , ~p&quot;5.2&quot; ) end ) [ &quot;Influenza&quot; , &quot;PCV 13&quot; , &quot;DTaP-Hep B-IPV&quot; ]","ref":"HL7.Query.html#map/2"},{"type":"function","title":"HL7.Query.new/1","doc":"Creates an HL7.Query struct that selects an entire HL7 Message. This step is implicitly carried out by most other functions in this module. As it involves parsing an HL7 message, one should cache this result if invoked repeatedly.","ref":"HL7.Query.html#new/1"},{"type":"function","title":"HL7.Query.number_set_ids/1","doc":"Updates the set numbers in each segment's first field to be their respective selection indices.","ref":"HL7.Query.html#number_set_ids/1"},{"type":"function","title":"HL7.Query.prepend/2","doc":"Prepends a segment or list of segments to the segments in each of the current selections.","ref":"HL7.Query.html#prepend/2"},{"type":"function","title":"HL7.Query.reject/2","doc":"Rejects (deletes) segments within selections by blacklisting one or more segment types. Accepts either a segment name, list of acceptable names, or a function that takes an HL7.Query (containing one sub-selected segment at a time) and returns a boolean reject value. Examples iex&gt; import HL7.Query iex&gt; HL7.Examples . nist_immunization_hl7 ( ) ...&gt; |&gt; reject ( [ &quot;OBX&quot; , &quot;RXA&quot; , &quot;RXR&quot; ] ) ...&gt; |&gt; root ( ) ...&gt; |&gt; get_segment_names ( ) [ &quot;MSH&quot; , &quot;PID&quot; , &quot;ORC&quot; , &quot;ORC&quot; , &quot;ORC&quot; ]","ref":"HL7.Query.html#reject/2"},{"type":"function","title":"HL7.Query.reject_z_segments/1","doc":"Rejects (deletes) Z-segments in all selections.","ref":"HL7.Query.html#reject_z_segments/1"},{"type":"function","title":"HL7.Query.replace/2","doc":"Replaces all segments in each selection. The given fun should accept an HL7.Query (referencing a single selection) and return a list of replacement segments (in parsed list format).","ref":"HL7.Query.html#replace/2"},{"type":"function","title":"HL7.Query.replace_parts/3","doc":"","ref":"HL7.Query.html#replace_parts/3"},{"type":"function","title":"HL7.Query.root/1","doc":"Selects the entire an HL7.Query into an HL7.Message .","ref":"HL7.Query.html#root/1"},{"type":"function","title":"HL7.Query.select/2","doc":"Selects or sub-selects segment groups in an HL7 message using a segment selector or filter function. iex&gt; import HL7.Query iex&gt; HL7.Examples . nist_immunization_hl7 ( ) ...&gt; |&gt; select ( &quot;OBX&quot; ) ...&gt; |&gt; select ( fn q -&gt; find_first ( q , ~p&quot;1&quot; ) != &quot;1&quot; end ) ...&gt; |&gt; delete ( ) ...&gt; |&gt; root ( ) ...&gt; |&gt; get_segment_names ( ) [ &quot;MSH&quot; , &quot;PID&quot; , &quot;ORC&quot; , &quot;RXA&quot; , &quot;RXR&quot; , &quot;OBX&quot; , &quot;ORC&quot; , &quot;RXA&quot; , &quot;ORC&quot; , &quot;RXA&quot; , &quot;RXR&quot; , &quot;OBX&quot; ]","ref":"HL7.Query.html#select/2"},{"type":"macro","title":"HL7.Query.sigil_g/2","doc":"","ref":"HL7.Query.html#sigil_g/2"},{"type":"macro","title":"HL7.Query.sigil_p/2","doc":"Checks the format of an hl7 path at compile time and returns an Path","ref":"HL7.Query.html#sigil_p/2"},{"type":"function","title":"HL7.Query.to_console/1","doc":"Outputs an ANSI representation of an HL7.Query with corresponding selection indices on the left.","ref":"HL7.Query.html#to_console/1"},{"type":"function","title":"HL7.Query.to_message/1","doc":"Converts an HL7.Query into an HL7.Message .","ref":"HL7.Query.html#to_message/1"},{"type":"function","title":"HL7.Query.update/3","doc":"Updates segment parts of all selected segments, iterating through each selection. A replacement function accepts an HL7.Query containing one selection with its part property set to the value found using the field_selector . Examples iex&gt; import HL7.Query iex&gt; HL7.Examples . nist_immunization_hl7 ( ) ...&gt; |&gt; update ( ~p&quot;OBX-3.2&quot; , fn q -&gt; &quot;TEST: &quot; &lt;&gt; q . part end ) ...&gt; |&gt; find_all ( ~p&quot;OBX-3.2&quot; ) ...&gt; |&gt; List . first ( ) &quot;TEST: Vaccine funding program eligibility category&quot; iex&gt; import HL7.Query iex&gt; HL7.Examples . wikipedia_sample_hl7 ( ) ...&gt; |&gt; select ( &quot;PID&quot; ) ...&gt; |&gt; update ( ~p&quot;5.2&quot; , &quot;UNKNOWN&quot; ) ...&gt; |&gt; find_first ( ~p&quot;PID-5.2&quot; ) &quot;UNKNOWN&quot;","ref":"HL7.Query.html#update/3"},{"type":"type","title":"HL7.Query.content_hl7/0","doc":"","ref":"HL7.Query.html#t:content_hl7/0"},{"type":"type","title":"HL7.Query.content_or_query_hl7/0","doc":"","ref":"HL7.Query.html#t:content_or_query_hl7/0"},{"type":"type","title":"HL7.Query.parsed_hl7/0","doc":"","ref":"HL7.Query.html#t:parsed_hl7/0"},{"type":"type","title":"HL7.Query.parsed_or_query_hl7/0","doc":"","ref":"HL7.Query.html#t:parsed_or_query_hl7/0"},{"type":"type","title":"HL7.Query.raw_hl7/0","doc":"","ref":"HL7.Query.html#t:raw_hl7/0"},{"type":"type","title":"HL7.Query.t/0","doc":"","ref":"HL7.Query.html#t:t/0"},{"type":"module","title":"HL7.RawMessage","doc":"Contains the raw text of an HL7 message alongside parsed header metadata from the MSH segment. Use HL7.Message.raw/1 to generate the HL7.RawMessage struct.","ref":"HL7.RawMessage.html"},{"type":"type","title":"HL7.RawMessage.t/0","doc":"","ref":"HL7.RawMessage.html#t:t/0"},{"type":"module","title":"HL7.Segment","doc":"Filter, parse and modify individual HL7 segments and their fragments.","ref":"HL7.Segment.html"},{"type":"function","title":"HL7.Segment.get_part/5","doc":"Extracts content from a parsed HL7 segment, returning nested data by applying each supplied index in turn. Please note that HL7 indices start at 1.","ref":"HL7.Segment.html#get_part/5"},{"type":"function","title":"HL7.Segment.leftmost_value/1","doc":"","ref":"HL7.Segment.html#leftmost_value/1"},{"type":"function","title":"HL7.Segment.replace_part/6","doc":"Updates content within a parsed HL7 segment, returning a modified segment whose data has been transformed at the given indices (starting at 1 as with HL7's convention). The transform can be either a string , list or fn old_data -&gt; new_data .","ref":"HL7.Segment.html#replace_part/6"},{"type":"type","title":"HL7.Segment.content_hl7/0","doc":"","ref":"HL7.Segment.html#t:content_hl7/0"},{"type":"type","title":"HL7.Segment.fragment_hl7/0","doc":"","ref":"HL7.Segment.html#t:fragment_hl7/0"},{"type":"type","title":"HL7.Segment.parsed_hl7/0","doc":"","ref":"HL7.Segment.html#t:parsed_hl7/0"},{"type":"type","title":"HL7.Segment.raw_hl7/0","doc":"","ref":"HL7.Segment.html#t:raw_hl7/0"},{"type":"type","title":"HL7.Segment.segment_hl7/0","doc":"","ref":"HL7.Segment.html#t:segment_hl7/0"},{"type":"module","title":"HL7.Separators","doc":"Contains HL7 delimiter information (optionally specified by the end system) used to parse or generate HL7 messages.","ref":"HL7.Separators.html"},{"type":"function","title":"HL7.Separators.new/1","doc":"","ref":"HL7.Separators.html#new/1"},{"type":"function","title":"HL7.Separators.new/2","doc":"","ref":"HL7.Separators.html#new/2"},{"type":"type","title":"HL7.Separators.t/0","doc":"","ref":"HL7.Separators.html#t:t/0"},{"type":"extras","title":"Elixir HL7","doc":"Note: We are now building a simpler and more Elixir-friendly API for this library, centered on the HL7 and HL7.Path modules. These will hopefully lead to the deprecation of HL7.Query and much of the related code. These will likely not be removed for some time, and their removal will coincide with a major version release. For now, the two systems can exchange data when needed. An Elixir library for working with HL7 v2.x healthcare data Elixir HL7 provides functions to parse, query and modify healthcare data that conforms to the HL7 v2.x standards. It should be able to reconstruct any HL7 Message without data loss or corruption. It also provides basic support for reading HL7 file streams with configurable delimiters (MLLP included). This library has been tested on a fairly wide variety of real-world HL7 messages to ensure correctness and flexibility. You can learn more about HL7 here: The official HL7 website ( hl7.org ) Wikipedia's HL7 article Please report an issue if something appears to be handled incorrectly.","ref":"readme.html"},{"type":"extras","title":"Elixir HL7 - Getting started","doc":"Full documentation can be found at hex.pm . Add this library to your mix.exs file: defp deps do [ { :elixir_hl7 , &quot;~&gt; 0.9.2&quot; } ] end Check out the HL7.Examples module for sample data that you can use to explore the API.","ref":"readme.html#getting-started"},{"type":"extras","title":"Elixir HL7 - Route","doc":"HL7 messages can be minimally validated to gather header (MSH segment) information for quick routing and acknowledgements. iex&gt; hl7_text = HL7.Examples . wikipedia_sample_hl7 ( ) ...&gt; raw_msg = HL7.Message . raw ( hl7_text ) ...&gt; raw_msg . header . message_type &quot;ADT&quot; See the HL7.RawMessage and HL7.Header modules for more information.","ref":"readme.html#route"},{"type":"extras","title":"Elixir HL7 - Parse","doc":"HL7 messages can be fully parsed into lists of lists and strings to provide a compact representation of the message structure. One could grab the 2nd segment in a message: iex&gt; HL7.Examples . wikipedia_sample_hl7 ( ) ...&gt; |&gt; HL7.Message . to_list ( ) ...&gt; |&gt; Enum . at ( 1 ) [ &quot;EVN&quot; , &quot;&quot; , &quot;200605290901&quot; , &quot;&quot; , &quot;&quot; , &quot;&quot; , &quot;200605290900&quot; ] Or get the field value of RXA-5.2 (finding the first RXA segment's 5th field, 1st repetition, 2nd component): iex&gt; HL7.Examples . nist_immunization_hl7 ( ) ...&gt; |&gt; HL7.Message . find ( &quot;RXA&quot; ) ...&gt; |&gt; HL7.Segment . get_part ( 5 , 1 , 2 ) &quot;Influenza&quot; It's also possible to modify the data within a segment (but it is much easier to manipulate messages using the HL7.Query module): iex&gt; HL7.Examples . wikipedia_sample_hl7 ( ) ...&gt; |&gt; HL7.Message . find ( &quot;EVN&quot; ) ...&gt; |&gt; HL7.Segment . replace_part ( &quot;extra data&quot; , 5 , 2 , 1 ) [ &quot;EVN&quot; , &quot;&quot; , &quot;200605290901&quot; , &quot;&quot; , &quot;&quot; , [ &quot;&quot; , &quot;&quot; , [ &quot;&quot; , &quot;extra data&quot; ] ] , &quot;200605290900&quot; ] See the HL7.Message and HL7.Segment modules for more information.","ref":"readme.html#parse"},{"type":"extras","title":"Elixir HL7 - Query","doc":"Advanced manipulation and analysis of HL7 messages can be performed with the HL7.Query module. It supports a pipeline-friendly API modeled after jQuery and D3, allowing set-based document operations and queries. Messages can be broken into groups using a segment selector (similar to a CSS selector string) that denotes optional and repeating segments in potentially nested hierarchies. Individual segments can be decomposed using a field selector to reference specific field, repetition, component and subcomponent indices. Note that all HL7.Query selections implicitly retain the entire message structure such that elements can be selected, modified and then used to reconstruct a new HL7 message. The act of selecting something never modifies the content of a message. Applying other methods to a selection, such as delete, filter, append, etc., does modify the actual message content. For instance, this would select all textual diagnoses (DG1-3.2) associated with a patient visit (PV1): iex&gt; import HL7.Query iex&gt; HL7.Examples . nist_syndromic_hl7 ( ) ...&gt; |&gt; select ( &quot;PV1 [{DG1}]&quot; ) ...&gt; |&gt; select ( &quot;DG1&quot; ) ...&gt; |&gt; find_all ( ~p&quot;3.2&quot; ) [ &quot;Cryptosporidiosis&quot; , &quot;Dehydration&quot; , &quot;Diarrhea&quot; ] The statement select(&quot;PV1 [{DG1}]&quot;) grabs a list of segment groups containing a PV1 segment and any DG1 segments that might follow it. Thus, we would select one group containing a PV1 segment and three DG1 segments. [ [ # 1 group of 4 segments [ &quot;PV1&quot; , &quot;1&quot; , &quot;(data truncated to fit)&quot; ] , [ &quot;DG1&quot; , &quot;1&quot; , &quot;&quot; , [ [ &quot;0074&quot; , &quot;Cryptosporidiosis&quot; , &quot;I9CDX&quot; ] ] , &quot;&quot; , &quot;&quot; , &quot;F&quot; ] , [ &quot;DG1&quot; , &quot;2&quot; , &quot;&quot; , [ [ &quot;27651&quot; , &quot;Dehydration&quot; , &quot;I9CDX&quot; ] ] , &quot;&quot; , &quot;&quot; , &quot;F&quot; ] , [ &quot;DG1&quot; , &quot;3&quot; , &quot;&quot; , [ [ &quot;78791&quot; , &quot;Diarrhea&quot; , &quot;I9CDX&quot; ] ] , &quot;&quot; , &quot;&quot; , &quot;F&quot; ] ] ] Then select(&quot;DG1&quot;) creates three groups of individual DG1 segments by searching within the confines of the prior selection. [ # 3 groups of 1 segment each [ [ &quot;DG1&quot; , &quot;1&quot; , &quot;&quot; , [ [ &quot;0074&quot; , &quot;Cryptosporidiosis&quot; , &quot;I9CDX&quot; ] ] , &quot;&quot; , &quot;&quot; , &quot;F&quot; ] ] , [ [ &quot;DG1&quot; , &quot;2&quot; , &quot;&quot; , [ [ &quot;27651&quot; , &quot;Dehydration&quot; , &quot;I9CDX&quot; ] ] , &quot;&quot; , &quot;&quot; , &quot;F&quot; ] ] , [ [ &quot;DG1&quot; , &quot;3&quot; , &quot;&quot; , [ [ &quot;78791&quot; , &quot;Diarrhea&quot; , &quot;I9CDX&quot; ] ] , &quot;&quot; , &quot;&quot; , &quot;F&quot; ] ] ] Finally, find_all(~p&quot;3.2&quot;) will return a flattened list of data containing the 3rd field, 1st repetition (the default), 2nd component for each selected segment. [ &quot;Cryptosporidiosis&quot; , &quot;Dehydration&quot; , &quot;Diarrhea&quot; ] Alternately, one could select and remove every diagnosis tied to a patient visit and then output a modified HL7 message: iex&gt; import HL7.Query iex&gt; HL7.Examples . nist_syndromic_hl7 ( ) ...&gt; |&gt; select ( &quot;PV1 [{DG1}]&quot; ) ...&gt; |&gt; select ( &quot;DG1&quot; ) ...&gt; |&gt; delete ( ) ...&gt; |&gt; to_string ( ) &quot;MSH|^~ \\\\ &amp;||LakeMichMC^9879874000^NPI|||201204020040||ADT^A03^ADT_A03|NIST-SS-003.32|P|2.5.1|||||||||PH_SS-NoAck^SS Sender^2.16.840.1.114222.4.10.3^ISO \\r EVN||201204020030|||||LakeMichMC^9879874000^NPI \\r PID|1||33333^^^^MR||^^^^^^~^^^^^^S|||F||2106-3^^CDCREC|^^^^53217^^^^55089|||||||||||2186-5^^CDCREC \\r PV1|1||||||||||||||||||33333_001^^^^VN|||||||||||||||||09||||||||201204012130 \\r OBX|1|CWE|SS003^^PHINQUESTION||261QE0002X^Emergency Care^NUCC||||||F \\r OBX|2|NM|21612-7^^LN||45|a^^UCUM|||||F \\r OBX|3|CWE|8661-1^^LN||^^^^^^^^Diarrhea, stomach pain, dehydration||||||F \\r &quot; The following query extracts each Common Order (ORC) group's OBX segments and outputs a list of each order's associated vaccine types. iex&gt; import HL7.Query iex&gt; HL7.Examples . nist_immunization_hl7 ( ) ...&gt; |&gt; select ( &quot;ORC [RXA] [RXR] {OBX}&quot; ) ...&gt; |&gt; filter ( fn q -&gt; find_first ( q , ~p&quot;3.2&quot; ) == &quot;vaccine type&quot; end ) ...&gt; |&gt; map ( fn q -&gt; find_all ( q , ~p&quot;5.2&quot; ) end ) [ [ &quot;Influenza, unspecified formulation&quot; ] , [ &quot;DTaP&quot; , &quot;Polio&quot; , &quot;Hep B, unspecified formulation&quot; ] ] See the HL7.Query module for more information.","ref":"readme.html#query"},{"type":"extras","title":"Elixir HL7 - Create","doc":"HL7 messages can be constructed from scratch with the HL7.Message module. Passing an HL7.Header struct to HL7.Message.new/1 will produce a base message upon which you can add additional segments. These can be appended as list data. The final raw message can be produced by invoking the to_string/1 protocol on either the HL7.Query or HL7.Message structs.","ref":"readme.html#create"},{"type":"extras","title":"Elixir HL7 - Files","doc":"The HL7 module contains utility functions to open file streams of HL7 message content with support for MLLP and standard :line storage. Other formats are somewhat supported by specifying expected prefix and suffix delimiters between messages.","ref":"readme.html#files"},{"type":"extras","title":"Elixir HL7 - Sockets","doc":"A separate library, Elixir-MLLP, exists to manage MLLP connections. MLLP is a simple protocol on top of TCP that is commonly used for sending and receiving HL7 messages.","ref":"readme.html#sockets"},{"type":"extras","title":"Elixir HL7 - Status","doc":"This project is approaching a v1.0 release. The API is mostly stable at this point. Also, please be aware of the details of the license (Apache 2.0). Roadmap Extending the HL7 base namespace to provide a simpler and more powerful API. License Elixir-HL7 source code is released under Apache 2 License. Check the LICENSE file for more information.","ref":"readme.html#status"}]